@@ -206,22 +206,7 @@ def rm_rf(path):
         if os.path.isfile(path) or os.path.islink(path):
             os.unlink(path)
         elif os.path.isdir(path):
-            subdirs = []
-            for root, dirs, files in os.walk(path, followlinks=False):
-                for tf in files:
-                    os.unlink(os.path.join(root, tf))
-                with os.scandir(root) as iterscan:
-                    for item in iterscan:
-                        if item.is_symlink():
-                            os.unlink(item.path)
-                subdirs.extend((os.path.join(root, td) for td in dirs))
-            for subdir in reversed(subdirs):
-                os.rmdir(subdir)
-            for root, dirs, files in os.walk(path, followlinks=False,
-                                                   topdown=False):
-                for td in dirs:
-                    os.removedirs(os.path.join(root, td))
-            os.removedirs(path)
+            shutil.rmtree(path)
         return True
     except (OSError, IOError):
         pass
