@@ -1,10 +1,161 @@
 # -*- coding: utf-8 -*-
 from __future__ import print_function
 
-# import pytest
+import pytest
 
 class TestImporting(object):
     
+    def test_proxy_module_for_reals(self, consts):
+        from clu.importing import ProxyModule, Registry
+        
+        overrides = dict(PROJECT_NAME='yodogg',
+                         PROJECT_PATH='/Users/fish/Dropbox/CLU/clu/tests/yodogg/yodogg',
+                         BASEPATH='/Users/fish/Dropbox/CLU/clu/tests/yodogg')
+        
+        try:
+            
+            class testing1_overridden_consts(ProxyModule):
+                targets = (overrides, consts)
+            
+            from clu.app import testing1_overridden_consts as overridden
+            
+            assert overridden.USER == consts.USER
+            assert overridden.BUILTINS == consts.BUILTINS
+            assert overridden.PROJECT_NAME == 'yodogg'
+            assert overridden.PROJECT_PATH.endswith('yodogg')
+            assert overridden.BASEPATH.endswith('yodogg')
+            
+            assert not hasattr(overridden, 'targets')
+            assert not hasattr(overridden, 'target_dicts')
+            
+            with pytest.raises(AttributeError) as exc:
+                assert overridden.YODOGG
+            assert "has no attribute" in str(exc.value)
+            
+            with pytest.raises(AttributeError) as exc:
+                assert overridden.add_targets
+            assert "has no attribute" in str(exc.value)
+        
+        finally:
+            Registry.unregister(testing1_overridden_consts.appname,
+                                testing1_overridden_consts.qualname)
+    
+    def test_module_dict_proxy_idea(self, consts):
+        from clu.dicts import ChainMap
+        from clu.importing import Module, Registry
+        from clu.typology import ismodule, ismapping
+        
+        overrides = dict(PROJECT_NAME='yodogg',
+                         PROJECT_PATH='/Users/fish/Dropbox/CLU/clu/tests/yodogg/yodogg',
+                         BASEPATH='/Users/fish/Dropbox/CLU/clu/tests/yodogg')
+        
+        try:
+            
+            class PutativeProxyModule(Module):
+                
+                def __init__(self, name, *targets, doc=None):
+                    """ Initialize a proxy-module instance.
+                        
+                        The signature for initializing a proxy module is the same
+                        as that for a class-based module – the proxy module class
+                        derives directly from the application-specific class-based
+                        module definition – with the optional addition of zero-to-N
+                        “targets”.
+                        
+                        Each target so named can be either a mapping-ish type, or a
+                        module. The proxy module will then use the list of targets
+                        – considerate of order – to construct a “clu.dicts.ChainMap”
+                        instance that pulls, in turn, from the target list.
+                        
+                        Attribute lookup on the proxy module instance will follow
+                        along through the “ChainMap” instances’ internal stack of
+                        mappings.
+                    """
+                    # Establish a base list of target dicts, and call up:
+                    self.target_dicts = []
+                    super(PutativeProxyModule, self).__init__(name, doc=doc)
+                    
+                    # Define inline target-processing function:
+                    def add_targets(self, *targets):
+                        """ Inline use-twice-and-destroy function for processing targets """
+                        if getattr(self, 'target_dicts', None) is None:
+                            self.target_dicts = []
+                        for target in targets:
+                            if target is None:
+                                continue
+                            if ismodule(target):
+                                self.target_dicts.append(target.__dict__)
+                                continue
+                            if ismapping(target):
+                                self.target_dicts.append(target)
+                                continue
+                    
+                    # Process any targets with which this instance
+                    # may have been constructed:
+                    add_targets(self, *targets)
+                    
+                    # Process and strip off class-level “targets” 
+                    # list attribute, if it exists:
+                    cls = type(self)
+                    if hasattr(cls, 'targets'):
+                        add_targets(self, *cls.targets)
+                        del cls.targets
+                
+                def __execute__(self):
+                    # Create the internal ChainMap instance:
+                    self.__proxies__ = ChainMap(*self.target_dicts)
+                    
+                    # Call up:
+                    super().__execute__()
+                    
+                    # Further unclutter the module namespace:
+                    del self.target_dicts
+                
+                def __getattr__(self, key):
+                    # N.B. AttributeError typenames (herein “PutativeProxyModule”)
+                    # must be hardcoded – using “self.name” leads to an infinite
+                    # recursion kertwang within “__getattr__(…)” – since “name”
+                    # is a property that uses “nameof(self)” which invariably will
+                    # attempt to get one or another nonexistant attributes from ‘self’.
+                    try:
+                        if not self.__dict__.get('_executed', False):
+                            raise KeyError(key)
+                        return self.__proxies__[key]
+                    except KeyError:
+                        typename = type(self).__name__
+                        raise AttributeError(f"‘{typename}’ proxy module has no attribute ‘{key}’")
+            
+            class testing0_overridden_consts(PutativeProxyModule):
+                # def __execute__(self):
+                #     self.add_targets(overrides, consts)
+                #     super().__execute__()
+                targets = (overrides, consts)
+            
+            from clu.app import testing0_overridden_consts as overridden
+            
+            assert overridden.USER == consts.USER
+            assert overridden.BUILTINS == consts.BUILTINS
+            assert overridden.PROJECT_NAME == 'yodogg'
+            assert overridden.PROJECT_PATH.endswith('yodogg')
+            assert overridden.BASEPATH.endswith('yodogg')
+            
+            assert not hasattr(overridden, 'targets')
+            assert not hasattr(overridden, 'target_dicts')
+            
+            with pytest.raises(AttributeError) as exc:
+                assert overridden.YODOGG
+            assert "has no attribute" in str(exc.value)
+            
+            with pytest.raises(AttributeError) as exc:
+                assert overridden.add_targets
+            assert "has no attribute" in str(exc.value)
+        
+        finally:
+            for clsmod in (PutativeProxyModule,
+                           testing0_overridden_consts):
+                Registry.unregister(clsmod.appname,
+                                    clsmod.qualname)
+    
     def test_module_export_within_execute(self):
         from clu.importing import Module, Registry, DO_NOT_INCLUDE
         from clu.exporting import Exporter
@@ -83,26 +234,20 @@ class TestImporting(object):
             assert youlike() == 'you like'
         
         finally:
-            
             Registry.unregister(derived.appname, derived.qualname)
     
-    def test_basic_module(self):
-        from clu.constants.consts import PROJECT_NAME
+    def test_basic_module(self, consts):
         from clu.naming import nameof
         from clu.importing import Registry, Module
         
-        m = Module(name=PROJECT_NAME)
+        m = Module(consts.PROJECT_NAME)
         assert m
-        assert m.appname == PROJECT_NAME
+        assert m.appname == consts.PROJECT_NAME
         assert m.appspace == 'app'
         assert m.__name__ == 'clu.app.clu'
-        assert nameof(m) == PROJECT_NAME
+        assert nameof(m) == consts.PROJECT_NAME
         
         assert len(Registry.monomers) > 0
-        
-        # with pytest.raises(AttributeError) as exc:
-        #     assert len(m.monomers) == 0
-        # assert "has no attribute" in str(exc.value)
         assert len(m.monomers) == 0
     
     def test_derived_modules(self):
@@ -117,9 +262,9 @@ class TestImporting(object):
         class MyDerivedOther(MyOtherModule):
             pass
         
-        o = MyOtherModule(name="other")
-        d = MyDerivedModule(name="derived")
-        O = MyDerivedOther(name="derived-other")
+        o = MyOtherModule("other")
+        d = MyDerivedModule("derived")
+        O = MyDerivedOther("derived-other")
         
         assert o
         assert d
@@ -140,9 +285,9 @@ class TestImporting(object):
             def yodogg(self):
                 return "Yo Dogg"
         
-        o = ThisOtherModule(name="other")
-        d = ThisDerivedModule(name="derived")
-        O = ThisDerivedOther(name="derived-other")
+        o = ThisOtherModule("other")
+        d = ThisDerivedModule("derived")
+        O = ThisDerivedOther("derived-other")
         
         assert o.yodogg()
         assert not d.yodogg()
@@ -207,7 +352,6 @@ class TestImporting(object):
             assert iheard() == 'I heard you like'
         
         finally:
-            
             Registry.unregister(derived.appname, derived.qualname)
     
     def test_initialize_types(self, dirname):
@@ -248,7 +392,6 @@ class TestImporting(object):
             assert iheard() == 'I heard you like'
         
         finally:
-            
             from clu.importing import Registry
             Registry.unregister(derived.appname, derived.qualname)
     
@@ -316,7 +459,6 @@ class TestImporting(object):
             assert youlike() == 'you like'
         
         finally:
-            
             Registry.unregister(derived.appname, derived.qualname)
     
     def test_SubModule_contextmanager_derived_import_statement(self):
@@ -362,4 +504,3 @@ class TestImporting(object):
         
         after = all_registered_modules()
         assert before == after
-        
