@@ -247,7 +247,8 @@ class TestPredicates(object):
         assert ThingyWithAttrs.iheard == 'you like attributes'
     
     @pytest.mark.TODO
-    def test_static_accessors(self, environment):
+    def test_static_accessors(self, environment, consts):
+        from clu.fs.misc import gethomedir
         from clu.predicates import isclasstype, pyattr
         from clu.predicates import attr, attrs, stattr, stattrs
         # TODO: test *_search and *_across static accessors:
@@ -259,8 +260,8 @@ class TestPredicates(object):
         
         # We have to use these irritating default environment values everywhere,
         # in case the testing environment is kertwanged:
-        home = environment.get('HOME', '/tmp')
-        user = environment.get('USER', 'nobody')
+        home = environment.get('HOME', gethomedir())
+        user = environment.get('USER', consts.USER)
         
         # Non-data descriptor wrapping R/O access to a named environment variable,
         # a default value for that variable, and the variables’ name:
@@ -295,8 +296,8 @@ class TestPredicates(object):
             __slots__ = ('yo', 'dogg', 'wtf')
             
             hax = ValueDescriptor('HAXXX')
-            HOME = EnvironmentName(default='/tmp')
-            USER = EnvironmentName(default='nobody')
+            HOME = EnvironmentName(default=gethomedir())
+            USER = EnvironmentName(default=consts.USER)
             
             def __init__(self):
                 self.yo: str = "YO"
@@ -310,8 +311,8 @@ class TestPredicates(object):
             dogg: str = "DOGG"
             
             wtf = ValueDescriptor('WTFFF')
-            HOME = EnvironmentName(default='/tmp')
-            USER = EnvironmentName(default='nobody')
+            HOME = EnvironmentName(default=gethomedir())
+            USER = EnvironmentName(default=consts.USER)
             
             def __init__(self):
                 self.hax: str = "HAXXX"
@@ -354,18 +355,18 @@ class TestPredicates(object):
         
         # Check statically obtained EnvironmentName instances,
         # from both Slotted and Dictish types and instances:
-        assert repr(stattr(Slotted,   'HOME')) == repr(EnvironmentName('HOME', default='/tmp'))
-        assert repr(stattr(Slotted(), 'HOME')) == repr(EnvironmentName('HOME', default='/tmp'))
-        assert repr(stattr(Slotted,   'USER')) == repr(EnvironmentName('USER', default='nobody'))
-        assert repr(stattr(Slotted(), 'USER')) == repr(EnvironmentName('USER', default='nobody'))
+        assert repr(stattr(Slotted,   'HOME')) == repr(EnvironmentName('HOME', default=gethomedir()))
+        assert repr(stattr(Slotted(), 'HOME')) == repr(EnvironmentName('HOME', default=gethomedir()))
+        assert repr(stattr(Slotted,   'USER')) == repr(EnvironmentName('USER', default=consts.USER))
+        assert repr(stattr(Slotted(), 'USER')) == repr(EnvironmentName('USER', default=consts.USER))
         assert repr(stattr(Slotted,   'HOME')) ==     "EnvironmentName<[HOME]>"
         assert repr(stattr(Slotted(), 'HOME')) ==     "EnvironmentName<[HOME]>"
         assert repr(stattr(Slotted,   'USER')) ==     "EnvironmentName<[USER]>"
         assert repr(stattr(Slotted(), 'USER')) ==     "EnvironmentName<[USER]>"
-        assert repr(stattr(Dictish,   'HOME')) == repr(EnvironmentName('HOME', default='/tmp'))
-        assert repr(stattr(Dictish(), 'HOME')) == repr(EnvironmentName('HOME', default='/tmp'))
-        assert repr(stattr(Dictish,   'USER')) == repr(EnvironmentName('USER', default='nobody'))
-        assert repr(stattr(Dictish(), 'USER')) == repr(EnvironmentName('USER', default='nobody'))
+        assert repr(stattr(Dictish,   'HOME')) == repr(EnvironmentName('HOME', default=gethomedir()))
+        assert repr(stattr(Dictish(), 'HOME')) == repr(EnvironmentName('HOME', default=gethomedir()))
+        assert repr(stattr(Dictish,   'USER')) == repr(EnvironmentName('USER', default=consts.USER))
+        assert repr(stattr(Dictish(), 'USER')) == repr(EnvironmentName('USER', default=consts.USER))
         assert repr(stattr(Dictish,   'HOME')) ==     "EnvironmentName<[HOME]>"
         assert repr(stattr(Dictish(), 'HOME')) ==     "EnvironmentName<[HOME]>"
         assert repr(stattr(Dictish,   'USER')) ==     "EnvironmentName<[USER]>"
@@ -674,10 +675,9 @@ class TestPredicates(object):
         assert slots_for(Dictish)   == tuple()
         assert slots_for(Dictish()) == tuple()
     
-    def test_applyto(self):
+    def test_applyto(self, consts):
         """ » Checking “apply_to(…)” core function from clu.predicates … """
         from string import capwords
-        from clu.constants.consts import ENCODING, SINGLETON_TYPES
         from clu.predicates import apply_to, isclasstype, typeof, uniquify
         from clu.typology import (numeric_types, string_types, bytes_types,
                                   callable_types, array_types, path_types)
@@ -701,7 +701,7 @@ class TestPredicates(object):
         istypelist = apply_to(isclasstype, all)
         maketypelist = apply_to(typeof, uniquify)
         
-        assert istypelist(SINGLETON_TYPES)
+        assert istypelist(consts.SINGLETON_TYPES)
         assert istypelist(numeric_types)
         assert istypelist(string_types)
         assert istypelist(bytes_types)
@@ -721,7 +721,7 @@ class TestPredicates(object):
                         lambda total: all(total),
                         "yo", "dogg", "I", "heard", "you", "love", "apply_to")
         
-        s = lambda by: str(by, encoding=ENCODING)
+        s = lambda by: str(by, encoding=consts.ENCODING)
         r = "Yo Dogg I Heard You Love Apply_to"
         assert apply_to(lambda thing: isinstance(thing, string_types) and thing or s(thing),
                         lambda total: capwords(" ".join(total)),
